pub struct Triangulation {
pub triangles: Vec<WeightedTriangle>,
pub used_vertices: Vec<WeightedVertex>,
pub ignored_vertices: Vec<WeightedVertex>,
pub cache: Vec<Vec<WeightedTriangle>>,
}Expand description
A triangulation of a set of vertices in 2-dimensional space.
Fields
triangles: Vec<WeightedTriangle>used_vertices: Vec<WeightedVertex>ignored_vertices: Vec<WeightedVertex>cache: Vec<Vec<WeightedTriangle>>Implementations
Sourceimpl Triangulation
impl Triangulation
Sourcepub fn new(starting_triangle: WeightedTriangle) -> Self
pub fn new(starting_triangle: WeightedTriangle) -> Self
Create a new trangulation with the given starting triangle.
pub fn triangles(&self) -> &Vec<WeightedTriangle>
pub fn triangles_mut(&mut self) -> &mut Vec<WeightedTriangle>
pub fn used_vertices(&self) -> &Vec<WeightedVertex>
pub fn used_vertices_mut(&mut self) -> &mut Vec<WeightedVertex>
pub fn ignored_vertices(&self) -> &Vec<WeightedVertex>
pub fn ignored_vertices_mut(&mut self) -> &mut Vec<WeightedVertex>