pub fn c_hull(points: &Vec<WeightedVertex>) -> Vec<WeightedVertex>Expand description
Compute the convex hull of the given points in 2D
pub fn c_hull(points: &Vec<WeightedVertex>) -> Vec<WeightedVertex>Compute the convex hull of the given points in 2D