pub fn get_fourth_point(
triangle: &WeightedTriangle,
edge: &WeightedEdge,
) -> WeightedVertexExpand description
Given an edge of the triangle and, retrieve the point not on the edge
pub fn get_fourth_point(
triangle: &WeightedTriangle,
edge: &WeightedEdge,
) -> WeightedVertexGiven an edge of the triangle and, retrieve the point not on the edge