is_flippable

Function is_flippable 

pub fn is_flippable(
    point: &WeightedVertex,
    edge: &WeightedEdge,
    pk: &WeightedVertex,
) -> bool
Check whether the edge is flippable in the ploygon described all four points.
We call T and e flippable if conv(T) is the underlying space of the induced subcomplex of T.