A 1-simplex and its two incident 2-simplices yield four points, of which all 2-simplices of the given triangulation that
consist of any permutation of 3 of these vertices form the induced subcomplex.
Check whether the edge is flippable in the ploygon described all four points.
“We call T and e flippable if conv(T) is the underlying space of the induced subcomplex of T.”
Deprecated: more efficient and readable version is keep_unique_elements; this is kept for learning purposes
Remove duplicates from a list of elements of type T.
So keeping only unique elemtents